

//indicate if the current pixel is within the boundary of a square to be drawn on screen
//
//inputs:
// horizonal,vertical counts from sync generator (gives the current pixel being addressed for disp.)
// hloc,vloc location to place the square : 0,0 is the top-left pixel MAX_X,MAX_Y is the bottom right
//
//outputs
// disp: indicates when the pixel addressed by hcount and vcount is within the square
// RGB: color to display when square is enabled, set by parameter (by default black)
module square_gen #(
	parameter R_VAL = 0,
	parameter G_VAL = 0,
	parameter B_VAL = 0)(
	input [9:0] hcount,
	input [9:0] vcount,

	input [9:0] hloc,
	input [9:0] vloc,
	
	output disp,
	output [7:0] R,
	output [7:0] G,
	output [7:0] B
);

	wire h_bound_en;
	wire v_bound_en;
	wire square_en;

	assign disp = square_en;
	
	assign R = R_VAL;
	assign G = G_VAL;
	assign B = B_VAL;


	//a square can be generated by enabling output when
	//the current pixel is within the bounds of the square:
	/*****
		below is an example 22x12 Frame, with a 4x4 square (illustarted with hashes),
		the square is contained in an intersect of a band of rows and a band of columns

	
			band of 4 consecutive columns
			which make up the vertical boundary (column 6-9)
		        |  | 
		        |  |
		        |  |111111111122
		  0123456789012345678901
		 |----------------------|
		 |      ||||            |0
		 |      ||||            |1
		 |      ||||            |2
		 |      ||||            |3
		 |------####------------|4-- 
		 |------####------------|5  band of 4 consecutive rows
		 |------####------------|6  makes up the horizontal boundary (row 4-7)
		 |------####------------|7--
		 |      ||||            |8
		 |      ||||            |9
		 |      ||||            |10
		 |      ||||            |11
		 |----------------------|


		pseudocode to detect if a square is in bounds based off inputs 'column' and 'row':
		
		
		if column >=6 and column <=9
			column_enable = 1 :current column is inside bound/band
		else
			column_enable = 0 :falls outside of bounds
	
		if row >=4 and row <= 7
			row_enable = 1
		else
			row_enable = 0

		if  row_enable ==1 and column_enable==1
			square_enable = 1  :both boundary requirements are met
		else
			square_enable = 0  :current pixel is OOB

			
		endpseudocode


		The example code above assumes the square is remained fixed at col6-9 and row4-7,
		For a non-static square, the comparisons would have to account for inputs 
		giving the location of the square

	*****/

	//pixel is 16 pixels wide
	//detect which "band" of columns for which it is enabled
	//the first column is this "band" is the input 'hloc'
	//the last column is the 15th column following the first
	
	assign h_bound_en = (
				(hcount >= hloc ) &
				(hcount < (hloc + 16) )
			    );

	//for vertical bound do much the same
	//detect the band of 16 rows starting with vloc
	
	assign v_bound_en = (
				(vcount >=vloc ) &
				(vcount < (vloc+16) )
		
			    );


	//enable the square when the current pixel is within the intersection 
	//of the vertical and horizontal bands
	assign square_en = h_bound_en & v_bound_en;



	//Help with using the square code  with the display ROM
	
	//indicate which pixel inside the square is being displayed
	//square has 16 rows and 16 colums, so 4-bits needed for each address
	//each pixel has a 4-bit row address and column address
	wire [3:0] sq_row;
	wire [3:0] sq_col;

	//Student task:
	//Figure out how the hcount and vcount
	//relate to the current pixel row (vertical) and column (horizontal) pixel counts
	assign sq_row =0;
	assign sq_col =0;
	
	


endmodule
