

//generates hs and vs signals
//for a 640x480 visible display
//800x525 counts per frame
module vga_sync(
	input pix_clk,
	input rst,
	output hs,
	output vs,
	output active_video,
	output [9:0] hcount,
	output [9:0] vcount
);
	
	wire vcnt_en;
	wire hactive;
	wire vactive;

	//horizontal sync generation
	//sync starts at begninning of line then ends before the front porch
	assign hs = hcount < 96;


	//vsync generation
	//sync starts at beginning of frame, ends after second line
	assign vs = vcount < 2;
	

	//vertical count increments at the end of each line
	//enable this for one clock cycle at the end of each line
	assign vcnt_en = (hcount == 799);


	assign hactive = (hcount >=144) & (hcount <=783);
	assign vactive = (vcount >=35) & (vcount <=514 );

	assign active_video = hactive & vactive;

	//instance a counte for horizontal
	counter #(.MAX_COUNT(799), .WIDTH(10) ) hcounter(
		.clk(pix_clk),
		.srst(rst),
		.en(1'b1),
		.count(hcount)
	);

	//vertical counter lives here
	counter #(.MAX_COUNT(524), .WIDTH(10) ) vcounter(
		.clk(pix_clk),
		.srst(rst),
		.en(vcnt_en),
		.count(vcount)
	);
	
endmodule



//counter that counts up to MAXCOUNT, then wraps around to zero
//reset is sychronous
//en is clock enable
module counter #(parameter MAX_COUNT=64, WIDTH=6)(
	input clk,
	input srst,
	input en,
	output [WIDTH-1:0] count
);

	reg [WIDTH-1:0] rcount;

	assign count = rcount;

	//describe behavior of counter
	always @(posedge clk)
	begin
		if(srst) 
			rcount<=0;	 //syncro reset
		else if (en)
		begin
			if(rcount==MAX_COUNT)
				rcount<=0;	 //reached final count
			else 
				rcount<=rcount+1; //other wise inc
		end
	end

endmodule
