
//wraps VGA display with a square generator
module vga_wrapper(

	input pix_clk,
	input rst,
	output hs,
	output vs,
	output vde,
	output [7:0] red,
	output [7:0] green,
	output [7:0] blue
);

	wire [9:0] disp_x;
	wire [9:0] disp_y;

	wire [7:0] sq_R;
	wire [7:0] sq_G;
	wire [7:0] sq_B;
	wire sq_en;

	//place the square somewhere in the top left quadrant of the screen
	localparam [9:0] sq_x = 10'd174;
	localparam [9:0] sq_y = 10'd65;

	//if pixel is in square bounds, drive the color from the square,
	//otherwise BG color (here we use a white screen
	assign red = sq_en ?sq_R : 8'hff;
	assign green = sq_en ?sq_G : 8'hff;
	assign blue = sq_en ?sq_B : 8'hff;

	vga_sync sync_inst(
		.pix_clk(pix_clk),
		.rst(rst),
		.hs(hs),
		.vs(vs),
		.active_video(vde),
		.hcount(disp_x),
		.vcount(disp_y)
	);

	square_gen #(.R_VAL(255),.G_VAL(70),.B_VAL(229)) sq_inst(
		.hcount(disp_x),
		.vcount(disp_y),
		.hloc(sq_x),
		.vloc(sq_y),
		.disp(sq_en),
		.R(sq_R),
		.G(sq_G),
		.B(sq_B)
	);




endmodule
